IDS Peak Camera - Heros Devices 0.7.1 documentation

Skip to content
Back to top
View this page

# IDS Peak Camera

From: IDS Imaging Development Systems

Class: `herosdevices.hardware.ids.peak_camera.PeakCompatibleCamera`

Driver Quality Index: beta

Requires the following packages

ids-peak, ids-peak-ipl

A class to interface with IDS Peak cameras.

The class provides functionality to control and capture images from IDS Peak cameras. It manages camera configuration, acquisition, and data streaming.

Note

To access the camera as non-root user, you need to add the following udev rule to `/etc/udev/rules.d/99-ids.rules`:

    ATTRS{idVendor}=="1409", MODE="666"

The vendor library must be obtained from the [official website](https://en.ids-imaging.com/download-peak.html). Download the IDS peak archive file, unpack it at move the content of idspeak/ids/cti/ to a place where the user running the driver can access it. This path then needs to be specified via the lib_path argument (see example below)

Note

The `node_map` attribute provides access to the camera node map. If you need to set some special nodes you can use that. You can find the available nodes in the official API manuals:

- https://en.ids-imaging.com/manuals/ids-peak/ids-peak-api-documentation/2.16.0/en/index.html

- https://en.ids-imaging.com/manuals/ids-peak/ids-peak-user-manual/1.3.0/en/preface.html

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.ids.peak_camera.PeakCompatibleCamera` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
cam_id | <class ‘str’> |  | Serial number of the cam. Can be obtained for example from the ids-peak GUI. Note, that the id is only the first part of the value shown in the GUI, the part including the device type is not unique and may not be added to `cam_id`.
config_dict | <class ‘dict’> |  | Dict of configuration values like shown in the json example above.
default_config | str | None | None | Default key in `config_dict` to use.
lib_path | str | None | None | Path to vendor library.
reset_to_continuous | <class ‘bool’> | False | If True, the camera will be set to continuous acquisition mode on teardown.

The following JSON strings can be used to start a HERO device representation of `PeakCompatibleCamera` using BOSS.

    {
        "_id": "my_PeakCompatibleCamera",
        "classname": "herosdevices.hardware.ids.peak_camera.PeakCompatibleCamera",
        "arguments": {
            "cam_id": "1410d4e7c3b5",
            "config_dict": "default",
            "default_config": {
                "default": {
                    "ExposureTime": 1000,
                    "TriggerSelector": "ExposureStart",
                    "TriggerMode": "On",
                    "TriggerSource": "Software",
                    "AcquisitionMode": "MultiFrame",
                    "AcquisitionFrameCount": 5
                }
            },
            "lib_path": "/opt/idspeak/ids/cti/",
            "reset_to_continuous": false
        }
    }

generated from signature